##################################### info #################################################
## R Script generates statistical outputs for the profitability analyses (Figure 2) of crab plovers foraging on different
## crab species. Case study from Gommer, R et al. (2018). PloS ONE: Stomach fullness shapes prey choice decisions 
## in crab plovers (Dromas ardeola)
# --------------------------------------------------------------------------------------------------------
# Questions can be directed to: Roeland Bom (Roeland.Bom@nioz.nl) and Roy Gommer (roygommer@hotmail.com)
# --------------------------------------------------------------------------------------------------------

# The script runs with 	- R version 3.4.2 (2018-03-16);
# Needed data files:
	# Fig2.Macrophthalmus_AFDM.txt
	# Fig2.Portunus_AFDM.txt
	# Fig2.Portunus_AFDM_LO.txt
	# fig2mac_handle.txt
	# fig2por_handle.txt

# --------------------------------------------------------------------------------------------------------
##PROFITABILITY ANALYSES
###First analysing the energy ~ size relations for both crab species
###Then analysing the handling time ~ size relations to finally calculate -->
###profibility ~ size relations
# --------------------------------------------------------------------------------------------------------


# --------------------------------------------------------------------------------------------------------
###loading packages
library(lme4)
library(nlme)

par(mar=c(0.5, 0.5, 0.5, 0.5), mfcol=c(3,1),oma = c(3.5, 3.5, 1, 1))
# --------------------------------------------------------------------------------------------------------


#################################AFDM ~ size########################################
# --------------------------------------------------------------------------------------------------------

###Macrophthalmus###################################################################
mydata1 <- read.table('Fig2.Macrophthalmus_AFDM.txt', head = T)
mydata1$AFDM_mg <- mydata1$AFDM_g *1000

###percentage ash
mean (mydata1$Perc_Ash)
sd(mydata1$Perc_Ash)

###plotting data
plot(mydata1$AFDM_mg~mydata1$width_mm, xlab="Crab width (mm)", ylab="AFDM (g)",pch=24,cex=1.7, 
bg='grey', log='xy', xlim= c(2,90), ylim=c(1e-01, 8000),ann=FALSE, xaxt="n")
axis(side=1,labels=F)

###running model
m1 <- lm(log10(mydata1$AFDM_mg)~log10(mydata1$width_mm))
summary(m1)
m1

###calculate formula
10^-1.393
###y = 4.05e-02x^2.76

###caculating DM formula for mac
mydata1$DM_mg <- mydata1$DM_g * 1000

###running model
m01 <- lm(log10(mydata1$DM_mg)~log10(mydata1$width_mm))
summary(m01)
m01
10^-1.143
###y = 0.072 x ^ 2.80


####Portunus######################################################################
mydata2 <- read.table('Fig2.Portunus_AFDM.txt', head = T)
mydata2.2 <- subset(mydata2, Part == 'Carapax')
mydata2.2$AFDM_mg <- mydata2.2$AFDM_g * 1000

###plotting data
points(mydata2.2$AFDM_mg~mydata2.2$width_mm, xlab="Crab width (mm)", ylab="AFDM (g)", pch=21, cex=1.7,
bg="royalblue1", log='xy')

###running model
m2 <- lm(log10(mydata2.2$AFDM_mg)~log10(mydata2.2$width_mm))
summary(m2)
m2

###calculate formula
10^-1.377
###y = 4.20e-02x^2.53

###caculating DM formula for por
mydata2.2$DM_mg <- mydata2.2$DM_g * 1000

###running model
m02 <- lm(log10(mydata2.2$DM_mg)~log10(mydata2.2$width_mm))
summary(m02)
m02
10^-1.225
###y = 0.060 x ^ 2.58


###Portunis left overs############################################################
mydata3 <- read.table('Fig2.Portunus_AFDM_LO.txt', head = T)
mydata3$AFDM_mg <- mydata3$AFDM_g * 1000

###plotting data
points(mydata3$AFDM_mg~mydata3$Breedte, add= T, pch=23,bg = "white", cex=1.7)

###running model
m3 <- lm(log10(mydata3$AFDM_mg)~log10(mydata3$Breedte))
summary(m3)
m3

###calculating formula AFDM
10^-1.051
###y = 8.89e-02x^1.97

###calculate formala DM
mydata3$DM_mg <- mydata3$DM_g * 1000

###running model
m03 <- lm(log10(mydata3$DM_mg)~log10(mydata3$Breedte))
summary(m03)
m03
10^-1.384 
###y = 0.041 x ^ 2.44


###fit the lines to the data
###Macropthalmus
clip(2,27, 1e-01, 2e03)
abline(lm(log10(mydata1$AFDM_mg)~log10(mydata1$width_mm)),lwd=2, col='grey50')

###Portunus
clip(30,95,1e01, 1e+04)  
abline(lm(log10(mydata2.2$AFDM_mg)~log10(mydata2.2$width_mm)),lwd=2, col='royalblue4')

###Portunus predated
clip(29,85, 1e01, 1e+04)  
abline(lm(log10(mydata3$AFDM_mg)~log10(mydata3$Breedte)),lwd=2, col='black')

###Portunus minus the Portunus left overs
clip(30,95,1e01, 1e+04) 
x <- seq(30,95,0.01)
curve((4.20e-02*x^2.53)-(8.89e-02*x^1.96), add= T, col='red', lwd=2)
# --------------------------------------------------------------------------------------------------------



#################################handling ~ size########################################
# --------------------------------------------------------------------------------------------------------
###loading data for Macrophthalmus and Portunus
macrophthalmus <- read.table('fig2mac_handle.txt', head = T)
portunus <- read.table('fig2por_handle.txt', head = T)

plot(macrophthalmus$x~macrophthalmus$Choice_size, xlab="Crab width (mm)", 
ylab="Handling time (s)", pch=24,log='xy', bg='grey', cex=1.7, xlim=c(2,90), ylim=c(1,700),ann=FALSE, xaxt="n")
axis(side=1,labels=F)

points(portunus$x~portunus$Choice_size, xlab="Crab width (mm)", 
ylab="Handling time (s)", pch=21, cex=1.7, bg='royalblue1', log='xy')

clip(14,26, 1, 6)
abline(lm(log10(macrophthalmus$x)~log10(macrophthalmus$Choice_size)),lwd=2, col='grey50')

clip(32, 90, 15, 600)
abline(lm(log10(portunus$x)~log10(portunus$Choice_size)),lwd=2, col='royalblue4')

########################################HANDLING FORMULA Macropthalmus
mydata <- data.frame(macrophthalmus$x, macrophthalmus$Choice_size, macrophthalmus$BirdID)
names(mydata) <- c('handling','Choice_size','BirdID')

###run the model
m3 <- lme(log10(handling) ~ log10(Choice_size), random=~1|BirdID, data = mydata)
summary(m3)

###Formula
m3
10^-0.71598
### y = 0.19 x ^ 0.91

########################################HANDLING FORMULA Portunus
mydata <- data.frame(portunus$x, portunus$Choice_size, portunus$BirdID)
names(mydata) <- c('handling','Choice_size','BirdID')

###run the model
m1 <- lme(log10(handling)~log10(Choice_size), random=~1|BirdID, data = mydata)
summary(m1)

###Formula
m1
10^-2.59
### y = 0.0026 x ^ 2.72
# --------------------------------------------------------------------------------------------------------



#################################PROFITABILITY ~ SIZE###################################
# --------------------------------------------------------------------------------------------------------

###loading data for Macrophthalmus and Portunus
macrophthalmus <- read.table('fig2mac_handle.txt', head = T)
portunus <- read.table('fig2por_handle.txt', head = T)

###calculating profitability in mg/s
macrophthalmus$AFDM_Choice_mg <- macrophthalmus$AFDM_Choice * 1000
portunus$AFDM_Choice_mg <- portunus$AFDM_Choice * 1000
macrophthalmus$profit <- macrophthalmus$AFDM_Choice_mg/macrophthalmus$x
portunus$profit <- portunus$AFDM_Choice_mg/portunus$x

plot(macrophthalmus$profit~macrophthalmus$Choice_size, xlab="Crab width (mm)", 
ylab="Profitability (AFDM mg/s)", pch=24, cex=1.7, log='xy', bg='grey', xlim=c(2,90),ylim=c(2,170))
points(portunus$profit~portunus$Choice_size, xlab="Crab width (mm)", 
ylab="Profitability (AFDM mg/s)", pch=21, cex=1.7, bg='royalblue1', log='xy')

###adding legend to the graph

legend("bottomleft",expression(italic("Marcrophthalmus"), italic("Portunus"), paste(italic("Portunus "), "carapax")
,paste(italic("Portunus "), "obtained")), cex=1.1,col=c("black","black","black","red"), lty = c(1.5,1.5,1.5,1.5),
lwd=c(1,1,1,2), pch=c(24,21,23,NA),
pt.bg=c("grey","royalblue1","white",NA), pt.cex=c(1.7,1.7,1.7,0))

legend("bottomleft",c("","","",""), col=c("grey50","royalblue4","black","red"), cex=1.1, 
lty = c(1.5,1.5,1.5,1.5),lwd=c(2,2,2,2), pch=c(NA,NA,NA,NA), bty ='n')

legend("bottomleft",expression(italic("Marcrophthalmus"), italic("Portunus"), paste(italic("Portunus "), "carapax")
,paste(italic("Portunus "), "obtained")), cex=1.1,col=c("black","black","black","red"), lty = c(1.5,1.5,1.5,1.5),
lwd=c(NA,NA,NA,NA), pch=c(24,21,23,NA),pt.bg=c("grey","royalblue1","white",NA), pt.cex=c(1.7,1.7,1.7,0),bty='n')

clip(14,27, 20, 200)
abline(lm(log10(macrophthalmus$profit)~log10(macrophthalmus$Choice_size)),lwd=2, col='grey50')

clip(33, 84, 2, 30)
abline(lm(log10(portunus$profit)~log10(portunus$Choice_size)),lwd=2, col='royalblue4')

###adding text to the axis
mtext("Crab width (mm)", 1, adj=0.5, padj=2.8)

mtext("AFDM (mg)", 2, adj=4.2, padj=-2.8)
mtext("Handling time (s)", 2, adj=3.33, padj=-2.8)
mtext("Profitability (mg/s)", 2, adj=0.61, padj=-2.8)

mtext("(a)", 3, adj=0.01, padj=-34)
mtext("(b)", 3, adj=0.01, padj=-16.2)
mtext("(c)", 3, adj=0.01, padj=1.55)

########################################Profitability FORMULA Macropthalmus
mydata <- data.frame(macrophthalmus$e_h, macrophthalmus$Choice_size, macrophthalmus$BirdID)
names(mydata) <- c('profit','Choice_size','BirdID')

###run the model
m3 <- lme(log10(profit) ~ log10(Choice_size), random=~1|BirdID, data = mydata)
summary(m3)
###significant effect of size on profitability in Macropthalmus

###Formula
m3
10^-0.6516501
### y = 0.22 x ^ 1.85


########################################profitability FORMULA Portunus
mydata <- data.frame(portunus$e_h, portunus$Choice_size, portunus$BirdID)
names(mydata) <- c('profit','Choice_size','BirdID')

###run the model
m1 <- lme(log10(profit)~log10(Choice_size), random=~1|BirdID, data = mydata)
summary(m1)
###no significant effect of size on profitbality in Portunus

###Formula
m1
10^0.73747661
### y = 5.46 x ^ 0.03


#################profitability comparison Macropthalmus versus Portunus
mac <- data.frame(macrophthalmus$e_h, macrophthalmus$Choice_species, macrophthalmus$BirdID)
names(mac) <- c('profit', 'species', 'Bird')
por <- data.frame(portunus$e_h, portunus$Choice_species, portunus$BirdID)
names(por) <- c('profit', 'species', 'Bird')

all <- rbind(mac, por)
attach(all)
m1 <- lme(profit~species, random=~1|Bird)
summary(m1)
###Macrophthalmus higher profitability then Portunus
# --------------------------------------------------------------------------------------------------------




