##################################### info #################################################
## R Script generates digestive rate model (DRM; Figure 4) of crab plovers foraging 
## on different crab species. Case study from Gommer, R et al. (2018). PloS ONE: Stomach fullness shapes prey choice 
## decisions in crab plovers (Dromas ardeola)
# --------------------------------------------------------------------------------------------------------
# Questions can be directed to: Roeland Bom (Roeland.Bom@nioz.nl) and Roy Gommer (roygommer@hotmail.com)
# --------------------------------------------------------------------------------------------------------

# The script runs with 	- R version 3.4.2 (2018-03-16);
# Needed data files:
	# fig4mac.txt
	# fig4por.txt
# --------------------------------------------------------------------------------------------------------


######################################################DIGESTIVE RATE MODEL
# --------------------------------------------------------------------------------------------------------
###loading packages
library(RODBC)
library(nlme)

macrophthalmus <- read.table('fig4mac.txt', head = T)
portunus <- read.table('fig4por.txt', head = T)


###Mean and SE: e/h and k/h for Macropthalmus

###e/h
mean(macrophthalmus$e_h)  ##n=28
(se.mac <- sd(macrophthalmus$e_h)/sqrt(length(macrophthalmus$e_h)))

###k/h
mean(macrophthalmus$k_h)  ##n=28
(semac <- sd(macrophthalmus$k_h)/sqrt(length(macrophthalmus$k_h)))


###different sizes portunus

portunus_s <- subset(portunus, Choice_size <= 50)
portunus_l <- subset(portunus, Choice_size >= 60)

###Mean and SE: e/h and k/h for Portunus
###portunus_s (n=43)

mean(portunus_s$e_h)
se.por_s <- sd(portunus_s$e_h)/sqrt(length(portunus_s$e_h))

mean(portunus_s$k_h)
sepor_s <- sd(portunus_s$k_h)/sqrt(length(portunus_s$k_h))

##########################################################################

###portunus_l (n=23)

mean(portunus_l$e_h)
se.por_l <- sd(portunus_l$e_h)/sqrt(length(portunus_l$e_h))

mean(portunus_l$k_h)
sepor_l <- sd(portunus_l$k_h)/sqrt(length(portunus_l$k_h))


#########################################################################
#####################means and SEs
###means and SEs calculated above
e_h <- c(56.57329, 6.732431, 7.783074)
k_h <- c(52.12807, 2.134191, 2.481253 )
spe <- c('Macrophthalmus', 'small_Portunus', 'large_Portunus')
e_h_se <- c(5.267758, 0.5632549, 1.000706)
k_h_se <- c(4.881613, 0.1785958, 0.3176478)


#############################################dataframe with means and SEs
drm <- data.frame(e_h, k_h, spe, e_h_se, k_h_se)

###creating plot
x= c(0.000001)
y= c(0.000001)
plot(x~y, xlab=expression(paste('Ballast intake rate (', italic('k'),'/', italic('h'),')')), 
ylab=expression(paste('Energy intake rate (', italic('e'), '/', italic('h'),')')), xlim=c(0, 60), ylim=c(0, 60), 
bg=c('grey','royalblue1','royalblue1'), pch=c(24,22,21), cex=0)

###adding segments and arrows
segments(0, 0, x1 = 2.134191, y1 = 6.732431, col = 'black', lty = 1, lwd = 2)
segments(2.134191, 6.732431, x1 = 2.481253, y1 = 7.783074, col = 'black', lty = 1, lwd = 2)
segments(2.481253, 7.783074, x1 = 52.12807, y1 = 56.57329, col = 'black', lty = 2, lwd = 2)
segments(0, 0, x1 = 52.12807, y1 = 56.57329, col = 'black', lty = 1, lwd = 2)

arrows(drm$k_h, drm$e_h, x1 = drm$k_h, y1 = drm$e_h-drm$e_h_se, length = 0.05, angle = 90, code = 2)
arrows(drm$k_h, drm$e_h, x1 = drm$k_h, y1 = drm$e_h+drm$e_h_se, length = 0.05, angle = 90, code = 2)
arrows(drm$k_h, drm$e_h, x1 = drm$k_h-drm$k_h_se, y1 = drm$e_h, length = 0.05, angle = 90, code = 2)
arrows(drm$k_h, drm$e_h, x1 = drm$k_h+drm$k_h_se, y1 = drm$e_h, length = 0.05, angle = 90, code = 2)

###adding data points
points(drm$e_h~drm$k_h, xlab='Ballast intake rate (k/h)', ylab='Energy intake rate (e/h)', xlim=c(0, 60), 
ylim=c(0, 60), bg=c('grey','royalblue1','royalblue1'), pch=c(24,22,21), cex=2.5)

###zoom in window
segments(-2.5, 10, x1= 4.5, y1= 10, col= 'black', lty= 1, lwd= par("lwd"))
segments(4.5, 10, x1= 4.5, y1= -2.5, col= 'black', lty=1, lwd= par("lwd"))

legend("topleft", expression(italic("Macrophthalmus"), paste("small ", italic("Portunus")), paste("large ", 
italic("Portunus"))), pt.cex=2.5, cex=1.2, pt.bg=c("grey","royalblue1","royalblue1"), pch=c(24,22,21))
# --------------------------------------------------------------------------------------------------------



###zoom in
# --------------------------------------------------------------------------------------------------------
plot(x~y, xlab="", ylab ="",xlim=c(0, 2.8), ylim=c(0,10), 
col=c('royalblue1','royalblue1'), pch=c(16,15), cex=0)

segments(0, 0, x1 = 2.134191, y1 = 6.732431, col = 'black', lty = 1, lwd = 2)
segments(2.134191, 6.732431, x1 = 2.481253, y1 = 7.783074, col = 'black', lty = 1, lwd = 2)
segments(2.481253, 7.783074, x1 = 52.12807, y1 = 56.57329, col = 'black', lty = 2, lwd = 2)
segments(0, 0, x1 = 52.12807, y1 = 56.57329, col = 'black', lty = 1, lwd = 2)

arrows(drm$k_h, drm$e_h, x1 = drm$k_h, y1 = drm$e_h-drm$e_h_se, length = 0.05, angle = 90, code = 2)
arrows(drm$k_h, drm$e_h, x1 = drm$k_h, y1 = drm$e_h+drm$e_h_se, length = 0.05, angle = 90, code = 2)
arrows(drm$k_h, drm$e_h, x1 = drm$k_h-drm$k_h_se, y1 = drm$e_h, length = 0.05, angle = 90, code = 2)
arrows(drm$k_h, drm$e_h, x1 = drm$k_h+drm$k_h_se, y1 = drm$e_h, length = 0.05, angle = 90, code = 2)

points(drm$e_h~drm$k_h, xlab=expression(paste('Ballast intake rate (', italic('k'),'/', italic('h'), ')')), 
ylab=expression(paste('Energy intake rate (', italic('e'),'/', italic('h'), ')')), xlim=c(0, 2.8), ylim=c(0,10), 
bg=c('royalblue1','royalblue1'), pch=c(21,22), cex=2.5)

###digestive constraint ash
###0.0001598398
abline(v=0.1598398, col='red', lwd=2)
# --------------------------------------------------------------------------------------------------------

